==> media_contextual_crop_field_formatter-1.2.0.tar.gz: media_contextual_crop_field_formatter/src/Plugin/MediaContextualCropUseCase/References.php <==
<?php

namespace Drupal\media_contextual_crop_field_formatter\Plugin\MediaContextualCropUseCase;

use Drupal\image\Plugin\Field\FieldType\ImageItem;
use Drupal\media\MediaInterface;
use Drupal\media_contextual_crop\MediaContextualCropUseCasePluginBase;
use Drupal\Component\Serialization\Json;

/**
 * Plugin implementation of the media_contextual_crop_use_case.
 *
 * @MediaContextualCropUseCase(
 *   id = "references",
 *   label = @Translation("References"),
 *   default_folder = "media_contextual_crop"
 * )
 */
class References extends MediaContextualCropUseCasePluginBase {

  /**
   * {@inheritdoc}
   */
  public function isCompetent(ImageItem $item) {

    $entity_parent = $item->getEntity() ?? NULL;
    if ($entity_parent == NULL || !($entity_parent instanceof MediaInterface)) {
      return FALSE;
    }

    $crop_context_ref = $entity_parent->entity_reference_entity_modify ?? NULL;
    if ($crop_context_ref == NULL || $entity_parent->_referringItem == NULL) {
      return FALSE;
    }

    $field_definition = $entity_parent->getSource()
      ->getSourceFieldDefinition($entity_parent->bundle->entity);
    $item_class = $field_definition->getItemDefinition()->getClass();
    if ($item_class != ImageItem::class && !is_subclass_of($item_class, ImageItem::class)) {
      return FALSE;
    }

    return TRUE;

  }

  /**
   * {@inheritdoc}
   */
  public function processImageUrl(ImageItem $item, $old_uri, $image_style) {
    return $this->generateNewUri($item, $old_uri, $image_style);
  }

  /**
   * {@inheritdoc}
   */
  public function processImage(&$variables) {
    $new_uri = $this->generateNewUri($variables['item'], $variables['image']['#uri'], $variables['image']['#style_name']);
    if ($new_uri != NULL) {
      $variables['image']['#uri'] = $new_uri;
    }

  }

  /**
   * Generate New URI for current image.
   *
   * @param \Drupal\image\Plugin\Field\FieldType\ImageItem $item
   *   Image Item Data.
   * @param string $old_uri
   *   Uri of current image.
   * @param string $image_style
   *   Image style to apply.
   *
   * @return string|null
   *   Return new URI or NULL
   */
  private function generateNewUri(ImageItem $item, $old_uri, $image_style) {
    // Get parent entity of the image if exists.
    $entity_parent = $item->getEntity() ?? NULL;
    if ($entity_parent == NULL || !($entity_parent instanceof MediaInterface)) {
      return NULL;
    }

    $crop_data = [];

    // Get contextual modification, if exists.
    $crop_context_ref = $entity_parent->entity_reference_entity_modify ?? NULL;
    if ($crop_context_ref != NULL && $referringItem = $entity_parent->_referringItem) {
      $media_override = $referringItem->getValue() ?? [];
      // If there is overwritten data.
      if (isset($media_override['overwritten_property_map'])) {
        $crop_data = Json::decode($media_override['overwritten_property_map']);
      }
    }
    else {
      return NULL;
    }

    // Recover field image in the media.
    $media_image_field = NULL;
    $field_definition = $entity_parent->getSource()
      ->getSourceFieldDefinition($entity_parent->bundle->entity);
    $item_class = $field_definition->getItemDefinition()->getClass();
    if ($item_class == ImageItem::class || is_subclass_of($item_class, ImageItem::class)) {
      $media_image_field = $field_definition->getName();
    }
    else {
      return NULL;
    }

    // If there is contextual modification.
    $item_values = $item->getValue();
    $old_image = [
      '#uri' => $old_uri,
      '#width' => $item_values['width'],
      '#height' => $item_values['height'],
    ];

    if ($crop_data != [] && $media_image_field != NULL) {

      foreach ($crop_data as $field_name => $data_values) {
        if ($media_image_field == $field_name) {

          // Prepare Crop Data.
          $crop_settings = $this->getPluginSetting($data_values[0]);
          if (isset($crop_settings['plugin_id'])) {
            $crop_settings['context'] = $crop_context_ref;
            $crop_settings['image_style'] = $image_style;
            $crop_settings['base_crop_folder'] = 'media_contextual_crop';

            // Prepare Crop & generate new image path.
            $new_uri = $this->mccService->prepareCropImage($old_image, $crop_settings);
            return $new_uri;
          }
        }
      }
    }

    return NULL;
  }

  /**
   * Recover Crop settings.
   *
   * @param array $configuration
   *   Field information.
   *
   * @return array
   *   Crop settings.
   */
  private function getPluginSetting(array $configuration) {

    $plugin_definitions = $this->mccPluginManager->getDefinitions();

    foreach ($plugin_definitions as $plugin_id => $plugin) {
      foreach ($configuration as $key => $value) {

        $target_field = $plugin['target_field_name'];
        if ($key === $target_field) {
          return [
            'plugin_id' => $plugin_id,
            'crop_setting' => $value,
          ];
        }
      }
    }
    return [];
  }

}

==> media_contextual_crop_field_formatter-1.2.1.tar.gz: media_contextual_crop_field_formatter/src/Plugin/MediaContextualCropUseCase/References.php <==
<?php

namespace Drupal\media_contextual_crop_field_formatter\Plugin\MediaContextualCropUseCase;

use Drupal\image\Plugin\Field\FieldType\ImageItem;
use Drupal\media\MediaInterface;
use Drupal\media_contextual_crop\MediaContextualCropUseCasePluginBase;
use Drupal\Component\Serialization\Json;

/**
 * Plugin implementation of the media_contextual_crop_use_case.
 *
 * @MediaContextualCropUseCase(
 *   id = "references",
 *   label = @Translation("References"),
 *   default_folder = "media_contextual_crop"
 * )
 */
class References extends MediaContextualCropUseCasePluginBase {

  /**
   * {@inheritdoc}
   */
  public function isCompetent(ImageItem $item) {

    $entity_parent = $item->getEntity() ?? NULL;
    if (!($entity_parent instanceof MediaInterface)) {
      return FALSE;
    }

    $crop_context_ref = $entity_parent->entity_reference_entity_modify ?? NULL;
    if ($crop_context_ref == NULL || $entity_parent->_referringItem == NULL) {
      return FALSE;
    }

    $field_definition = $entity_parent->getSource()
      ->getSourceFieldDefinition($entity_parent->bundle->entity);
    $item_class = $field_definition->getItemDefinition()->getClass();
    if ($item_class != ImageItem::class && !is_subclass_of($item_class, ImageItem::class)) {
      return FALSE;
    }

    return TRUE;

  }

  /**
   * Generate New URI for current image.
   *
   * @param \Drupal\image\Plugin\Field\FieldType\ImageItem $item
   *   Image Item Data.
   * @param string $old_uri
   *   Uri of current image.
   * @param string $image_style
   *   Image style to apply.
   *
   * @return string|null
   *   Return new URI or NULL
   */
  public function getContextualUri(ImageItem $item, $old_uri, $image_style) {
    // Get parent entity of the image if exists.
    $entity_parent = $item->getEntity() ?? NULL;
    if (!($entity_parent instanceof MediaInterface)) {
      return NULL;
    }

    $crop_data = [];

    // Get contextual modification, if exists.
    $crop_context_ref = $entity_parent->entity_reference_entity_modify ?? NULL;
    if ($crop_context_ref != NULL && $referringItem = $entity_parent->_referringItem) {
      $media_override = $referringItem->getValue() ?? [];
      // If there is overwritten data.
      if (isset($media_override['overwritten_property_map'])) {
        $crop_data = Json::decode($media_override['overwritten_property_map']);
      }
    }
    else {
      return NULL;
    }

    // Recover field image in the media.
    $media_image_field = NULL;
    $field_definition = $entity_parent->getSource()
      ->getSourceFieldDefinition($entity_parent->bundle->entity);
    $item_class = $field_definition->getItemDefinition()->getClass();
    if ($item_class == ImageItem::class || is_subclass_of($item_class, ImageItem::class)) {
      $media_image_field = $field_definition->getName();
    }
    else {
      return NULL;
    }

    // If there is contextual modification.
    $item_values = $item->getValue();
    $old_image = [
      '#uri' => $old_uri,
      '#width' => $item_values['width'],
      '#height' => $item_values['height'],
    ];

    if ($crop_data != [] && $media_image_field != NULL) {

      foreach ($crop_data as $field_name => $data_values) {
        if ($media_image_field == $field_name) {

          // Prepare Crop Data.
          $crop_settings = $this->getPluginSetting($data_values[0]);
          if (isset($crop_settings['plugin_id'])) {
            $crop_settings['context'] = $crop_context_ref;
            $crop_settings['image_style'] = $image_style;
            $crop_settings['base_crop_folder'] = 'media_contextual_crop';

            // Prepare Crop & generate new image path.
            $new_uri = $this->mccService->prepareCropImage($old_image, $crop_settings);
            return $new_uri;
          }
        }
      }
    }

    return NULL;
  }

  /**
   * Recover Crop settings.
   *
   * @param array $configuration
   *   Field information.
   *
   * @return array
   *   Crop settings.
   */
  private function getPluginSetting(array $configuration) {

    $plugin_definitions = $this->mccPluginManager->getDefinitions();

    foreach ($plugin_definitions as $plugin_id => $plugin) {
      foreach ($configuration as $key => $value) {

        $target_field = $plugin['target_field_name'];
        if ($key === $target_field) {
          return [
            'plugin_id' => $plugin_id,
            'crop_setting' => $value,
          ];
        }
      }
    }
    return [];
  }

}
